=====
RFCDE
=====


The ``RFCDE`` package implements random forests for conditional density
estimation.

Installation
------------

RFCDE is availabile from PyPI; to install use \`pip\`

.. code:: shell

    pip install rfcde

Currently only Python 2.7 is supported due to compilation errors
with Cython in Python 3.6.
